pub struct GetUserPreferences {
pub session: UserSession,
}Expand description
Serialized arguments for the get_user_preferences server function.
Fields
session: UserSessionTrait Implementations
Sourceimpl Clone for GetUserPreferences
impl Clone for GetUserPreferences
Sourcefn clone(&self) -> GetUserPreferences
fn clone(&self) -> GetUserPreferences
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetUserPreferences
impl Debug for GetUserPreferences
Sourceimpl<'de> Deserialize<'de> for GetUserPreferences
impl<'de> Deserialize<'de> for GetUserPreferences
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetUserPreferences> for UserSession
impl From<GetUserPreferences> for UserSession
Sourcefn from(value: GetUserPreferences) -> Self
fn from(value: GetUserPreferences) -> Self
Converts to this type from the input type.
Sourceimpl From<UserSession> for GetUserPreferences
impl From<UserSession> for GetUserPreferences
Sourcefn from(session: UserSession) -> Self
fn from(session: UserSession) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for GetUserPreferences
impl Serialize for GetUserPreferences
Sourceimpl ServerFn for GetUserPreferences
impl ServerFn for GetUserPreferences
Sourceconst PATH: &'static str
const PATH: &'static str
A unique path for the server function’s API endpoint, relative to the host, including its prefix.
Sourcetype Client = BrowserClient
type Client = BrowserClient
The type of the HTTP client that will send the request from the client side. Read more
Sourcetype ServerRequest = ActixRequest
type ServerRequest = ActixRequest
The type of the HTTP request when received by the server function on the server side.
Sourcetype ServerResponse = ActixResponse
type ServerResponse = ActixResponse
The type of the HTTP response returned by the server function on the server side.
Sourcetype Output = Preferences
type Output = Preferences
The return type of the server function. Read more
Sourcetype InputEncoding = PostUrl
type InputEncoding = PostUrl
The
Encoding used in the request for arguments into the server function.Sourcetype OutputEncoding = Json
type OutputEncoding = Json
The
Encoding used in the response for the result of the server function.Sourcetype Error = NoCustomError
type Error = NoCustomError
The type of the custom error on
ServerFnError, if any. (If there is no
custom error type, this can be NoCustomError by default.)Sourcefn middlewares() -> Vec<Arc<dyn Layer<ActixRequest, ActixResponse>>>
fn middlewares() -> Vec<Arc<dyn Layer<ActixRequest, ActixResponse>>>
Middleware that should be applied to this server function.
Sourcefn run_body(
self,
) -> impl Future<Output = Result<Preferences, ServerFnError>> + Send
fn run_body( self, ) -> impl Future<Output = Result<Preferences, ServerFnError>> + Send
The body of the server function. This will only run on the server.
Sourcefn url() -> &'static str
fn url() -> &'static str
Returns
Self::PATH.Auto Trait Implementations
impl Freeze for GetUserPreferences
impl RefUnwindSafe for GetUserPreferences
impl Send for GetUserPreferences
impl Sync for GetUserPreferences
impl Unpin for GetUserPreferences
impl UnwindSafe for GetUserPreferences